pyMez.Code.InstrumentControl API documentation
Description: InstrumentControl is a subpackage designed for communication between a computer and the outside worl...

Top

# pyMez.Code.InstrumentControl module

InstrumentControl is a subpackage designed for communication between a computer and the outside world. It wraps NIVisa using the pyvisa module and integrates this wrapper with xml based instrument sheets found in `pyMez.Code.DataHandlers.XMLModels` examples of the xml can be found in pyMez/Instruments folder.

## Examples

    !#python
    >>from pyMez import *
    >>new_instrument=VisaInstrument("GPIB::21")
    >>print(new_instrument.idn)
    >>print(instrument.ask('*IDN?'))

## Help

`pyMez.Code`

Documentation Home | API Documentation Home | Examples | Index

Show source ≡

    """
    InstrumentControl is a subpackage designed for communication between a computer and the outside world. It wraps NIVisa
    using the pyvisa module and integrates this wrapper with xml based instrument sheets found in
    `pyMez.Code.DataHandlers.XMLModels` examples of the xml can be found in pyMez/Instruments folder.

    Examples
    --------
        !#python
        >>from pyMez import *
        >>new_instrument=VisaInstrument("GPIB::21")
        >>print(new_instrument.idn)
        >>print(instrument.ask('*IDN?'))

    Help
    ---------------
    <a href="../index.html">`pyMez.Code`</a>
    <div>
    <a href="../../../pyMez_Documentation.html">Documentation Home</a> |
    <a href="../../index.html">API Documentation Home</a> |
    <a href="../../../Examples/html/Examples_Home.html">Examples</a> |
    <a href="../../../Reference_Index.html">Index </a>
    </div>
    """

## Sub-modules

pyMez.Code.InstrumentControl.Experiments

Experiments is a base module for controlling experiments. Its purpose is to integrate multiple instrument data acquisition with data

## Help

`pyMez.Code.InstrumentControl`

Documentation Home | <a href=".....

pyMez.Code.InstrumentControl.Instruments

The Module Instruments Contains Classes and functions to control instruments; GPIB,RS232 and other visa instruments. Instrument control classes are wrappers around the pyvisa instrument class with static xml based metadata added in.

## Examples

    >> from pyMez import *
    >>...